Spatial analogues
=================

.. automodule:: xclim.analog
   :members: spatial_analogs


Analogue metrics API
--------------------

.. autofunction:: xclim.analog.friedman_rafsky

.. autofunction:: xclim.analog.kldiv

.. autofunction:: xclim.analog.kolmogorov_smirnov

.. autofunction:: xclim.analog.nearest_neighbor

.. autofunction:: xclim.analog.seuclidean

.. autofunction:: xclim.analog.szekely_rizzo

.. autofunction:: xclim.analog.zech_aslan

Utilities for developers
------------------------

.. autofunction:: xclim.analog.metric

.. autofunction:: xclim.analog.standardize
